#!/usr/bin/perl

# created by Lisa Pearl, 12/4/08
# code designed to take in a file containing only words (from child-directed speech)
# and use a dictionary file to convert the words in each line into their respective
# IPA encoding
#
# ex: input
# hear the kitty Morgie
#
# ex: dict.txt for the dictionary file
# ...
# kitty          .kIti -w
# ...
# ex: output
# h) D6 kIti m&gi
#
#
# calling createIPA.pl example
# createIPA.pl -inputfile brent-words.txt -outputfile Brent.pho -dictfile dict.txt


# begin getting command line options
process_options();

# open dictfile and dump all the translations into a hash
# will have to do some processing to get rid of "-w" and "." in front of translations

%dict = ();

open(DICT, "$opt_dictfile") or die("Couldn't open $opt_dictfile\n");
while(defined($dictfileline = <DICT>)){
  
  # extract word and IPA entry
  if($dictfileline =~ /^([\w|\@|\'|\-|\^]+)\s+(.+)\n$/){
 
    #check entry and ipa
    $word = $1;
    $ipa_form = $2;

    # remove -w and initial .
    $ipa_form =~ s/\-w ?//g;
    $ipa_form =~ s/\.//g;

    $dict{$word} = $ipa_form;
  }

}
close(DICT);

# now go through each line of inputfile and convert the words there using the %dict hash
open(IN, "$opt_inputfile");
open(OUT, ">$opt_outputfile");

while(defined($inputfileline = <IN>)){
  # line should be words divided by one space each
  # get rid of newline at the end
  # debug print
  #print("$inputfileline");

  chomp($inputfileline);

  @words_in_line = split(/ /,$inputfileline);

  # go through and replace
  $index = 0;
  while(defined($words_in_line[$index])){

    $word_to_find = $words_in_line[$index];
    # switch uppercase letters to lowercase letters
    $word_to_find =~ tr/[A-Z]/[a-z]/;

    # check to make sure word has some characters in it
    if($word_to_find =~ /\w/){
      # check to see if in dict hash

      if(exists ($dict{$word_to_find})){
	#print($dict{$word_to_find} );
	print(OUT $dict{$word_to_find});
      }else{
	print("DEBUG: *** $word_to_find not found in \%dict\n");
      }
  }
 
    $index++;
  }
   print(OUT "\n");

}

close(OUT);
close(IN);


sub process_options{
  
  use Getopt::Long;
  &GetOptions("inputfile=s", "outputfile=s", "dictfile=s"); # required filename options
}


